#! /bin/bash

DIMENSIONS=`xdpyinfo -ext all | awk '/dimensions/{printf"%s",$2}'`

#Performance - assume the debian location, and if this fails try looking for it.

if [ -x /usr/bin/Eterm ] ; then
    ETERM_BIN=/usr/bin/Eterm
else
    ETERM_BIN=`find /usr -name Eterm -print | grep bin`
fi

if [ -x $ETERM_BIN ] ; then
#	$ETERM_BIN -g $DIMENSIONS+0+0 -e ./eterm.sh
	$ETERM_BIN  -n 'Debian - Is your distribution this big?' -P /usr/lib/debroster/openlogo1.jpg@:s -f black -F '-*-courier-*-*-*-*-*-200-*-*-*-*-iso8859-1'  -c white -e /usr/lib/debroster/eterm.sh
elif [ -x /usr/X11R6/bin/xterm ]; then
#    echo no eterm
    /usr/X11R6/bin/xterm +bc -cr white +j -ms white +s +sb +si -wf -title 'Debian - Is your distribution this big?' -fn '-*-courier-*-*-*-*-*-200-*-*-*-*-iso8859-1' -e /usr/lib/debroster/eterm.sh
else
    echo "No valid terminal application!!"
fi

exit 0
